use derive_more::Display;

#[derive(Debug, Clone, Display, PartialEq, Eq, Copy)]
pub enum ContinueButton {
    Tab,
    Enter
}

#[cfg(target_family = "unix")]
use enigo::{KeyboardControllable};

#[cfg(target_family = "unix")]
pub fn type_text(text: &str) -> Result<(),()> {
    enigo::Enigo::default().key_sequence(text);
    Ok(())
}

#[cfg(target_family = "unix")]
pub fn click_button(button: ContinueButton) -> Result<(),()> {
    let button = match button {
        ContinueButton::Tab => enigo::Key::Tab,
        ContinueButton::Enter => enigo::Key::Return,
    };
    enigo::Enigo::default().key_click(button);
    Ok(())
}

#[cfg(target_family = "windows")]
pub fn type_text(text: &str) -> Result<(),()>{
    simulate::type_str(text).map_err(|_| ())
}

#[cfg(target_family = "windows")]
pub fn click_button(button: ContinueButton) -> Result<(),()> {
    let button = match button {
        ContinueButton::Tab => simulate::Key::Tab,
        ContinueButton::Enter => simulate::Key::Return,
    };
    simulate::send(button).map_err(|_| ())
}